(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     35242,        788]
NotebookOptionsPosition[     34504,        758]
NotebookOutlinePosition[     34846,        773]
CellTagsIndexPosition[     34803,        770]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Hyperbolic Paraboloid", "Section",
 CellChangeTimes->{{3.540783382390625*^9, 3.540783394171875*^9}, {
  3.540784725671875*^9, 3.540784737515625*^9}}],

Cell["\<\
http://mathworld.wolfram.com/HyperbolicParaboloid.html
Formed by distorting a square by moving pairs of opposite vertices along the \
endges of a cube until  they coincide with the vertices of the cube. In this \
position, the edges correspond to the edges of a tetrahedron.(The shape with \
rounded edges could be seen on certain potato chips.)\
\>", "Text",
 CellChangeTimes->{{3.540783429125*^9, 3.54078354253125*^9}, {
  3.5407839681875*^9, 3.5407839944375*^9}, {3.540784718828125*^9, 
  3.540784746046875*^9}, {3.54078521421875*^9, 3.540785228796875*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cub", "=", 
     RowBox[{"Scale", "[", 
      RowBox[{
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<Cube\>\"", ",", "\"\<Edges\>\""}], "]"}], ",", " ", 
       RowBox[{"2", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"tet", "=", 
     RowBox[{"{", 
      RowBox[{"Yellow", ",", 
       RowBox[{"Opacity", "[", "0.3", "]"}], ",", 
       RowBox[{"Rotate", "[", 
        RowBox[{
         RowBox[{"Rotate", "[", 
          RowBox[{
           RowBox[{"Scale", "[", 
            RowBox[{
             RowBox[{"PolyhedronData", "[", 
              RowBox[{"\"\<Tetrahedron\>\"", ",", "\"\<Faces\>\""}], "]"}], 
             ",", " ", 
             RowBox[{"2", 
              RowBox[{"Sqrt", "[", "2", "]"}], 
              RowBox[{"{", 
               RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], ",", 
           RowBox[{"-", 
            RowBox[{"ArcTan", "[", 
             RowBox[{"Sqrt", "[", "2", "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "]"}], ",", 
         RowBox[{"Pi", "/", "4"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"par", "=", 
     RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", " ", 
         RowBox[{"u", " ", ",", "v", " ", ",", " ", 
          RowBox[{"u", " ", "v", "  ", "mod"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"cub", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"RGBColor", "[", 
           RowBox[{"0.2", ",", "1", ",", "0.6"}], "]"}], ",", "par"}], "}"}], 
        ",", 
        RowBox[{"If", "[", 
         RowBox[{"tetn", ",", "tet", ",", 
          RowBox[{"{", "}"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
      RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mod", ",", "0", ",", "\"\<mod\>\""}], "}"}], ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tetn", ",", "False", ",", "\"\<show tetrahedron\>\""}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"False", ",", "True"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", "Manipulate"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.54075445790625*^9, 3.540754458671875*^9}, {
   3.540754582546875*^9, 3.54075458984375*^9}, {3.54075543025*^9, 
   3.540755453328125*^9}, {3.540755545671875*^9, 3.540755603328125*^9}, {
   3.54075563671875*^9, 3.540755637515625*^9}, 3.540755677375*^9, {
   3.540755897421875*^9, 3.5407559234375*^9}, {3.540756196578125*^9, 
   3.540756433171875*^9}, {3.540756481484375*^9, 3.54075651815625*^9}, {
   3.540756560671875*^9, 3.54075670209375*^9}, {3.54075680534375*^9, 
   3.540756808765625*^9}, {3.540758615203125*^9, 3.54075862159375*^9}, {
   3.54075873034375*^9, 3.540758770265625*^9}, {3.540783281171875*^9, 
   3.540783329171875*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`mod$$ = 0, $CellContext`tetn$$ = False, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`mod$$], 0, "mod"}, -1, 1}, {{
       Hold[$CellContext`tetn$$], False, "show tetrahedron"}, {False, True}}},
     Typeset`size$$ = {360., {178., 182.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`mod$1057$$ = 0, $CellContext`tetn$1058$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`mod$$ = 0, $CellContext`tetn$$ = False}, 
      "ControllerVariables" :> {
        Hold[$CellContext`mod$$, $CellContext`mod$1057$$, 0], 
        Hold[$CellContext`tetn$$, $CellContext`tetn$1058$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ($CellContext`cub = Scale[
          PolyhedronData["Cube", "Edges"], 2 {1, 1, 1}, {0, 0, 
          0}]; $CellContext`tet = {Yellow, 
          Opacity[0.3], 
          Rotate[
           Rotate[
            Scale[
             PolyhedronData["Tetrahedron", "Faces"], 2 Sqrt[2] {1, 1, 1}, {0, 
             0, 0}], -ArcTan[
              Sqrt[2]], {0, 1, 0}], Pi/4, {0, 0, 1}]}; $CellContext`par = Part[
          
          ParametricPlot3D[{$CellContext`u, $CellContext`v, $CellContext`u \
$CellContext`v $CellContext`mod$$}, {$CellContext`u, -1, 
            1}, {$CellContext`v, -1, 1}], 1]; Graphics3D[{$CellContext`cub, {
           RGBColor[0.2, 1, 0.6], $CellContext`par}, 
          If[$CellContext`tetn$$, $CellContext`tet, {}]}, Boxed -> False, 
         SphericalRegion -> True]), 
      "Specifications" :> {{{$CellContext`mod$$, 0, "mod"}, -1, 
         1}, {{$CellContext`tetn$$, False, "show tetrahedron"}, {
         False, True}}}, "Options" :> {TrackedSymbols -> Manipulate}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{405., {231., 236.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.540755650171875*^9, 3.5407556784375*^9}, 
   3.540755860828125*^9, {3.540755903890625*^9, 3.540755924625*^9}, {
   3.540756261484375*^9, 3.54075627571875*^9}, {3.5407563574375*^9, 
   3.540756380203125*^9}, {3.54075641190625*^9, 3.54075643359375*^9}, {
   3.54075648565625*^9, 3.540756540015625*^9}, 3.540756609578125*^9, {
   3.5407566784375*^9, 3.54075670296875*^9}, 3.54075680971875*^9, 
   3.540758585796875*^9, 3.540758623109375*^9, {3.540758732234375*^9, 
   3.540758770546875*^9}, 3.540761306078125*^9, 3.540761426859375*^9, {
   3.5407832716875*^9, 3.540783329421875*^9}, 3.540829830734375*^9, 
   3.540829910984375*^9}]
}, Open  ]],

Cell["\<\
Parabolic hyperboloid can also be generated by moving and rotating a striaght \
line. Therefore, it is a ruled surface, i.e. there is a projective line on \
the surface through any given point. The vertically moved square illustrates \
that horizontal section of hyperbolic paraboloid is hyperbole.
\
\>", "Text",
 CellChangeTimes->{{3.540783429125*^9, 3.54078354253125*^9}, {3.540783576*^9, 
   3.5407836548125*^9}, {3.54078399946875*^9, 3.540784018640625*^9}, 
   3.540784060859375*^9, {3.540784182234375*^9, 3.5407841949375*^9}, {
   3.540784762421875*^9, 3.540784865359375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"par", "=", 
      RowBox[{
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", " ", 
          RowBox[{"u", " ", ",", "v", " ", ",", " ", 
           RowBox[{"u", " ", "v"}]}], "  ", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"u", ",", 
           RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", 
           RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
         RowBox[{"Mesh", "\[Rule]", "None"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"bar", "=", 
      RowBox[{"Cylinder", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", "move"}], ",", 
            RowBox[{"-", "1"}], ",", " ", 
            RowBox[{
             RowBox[{"-", "1"}], " ", "+", "move"}]}], " ", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", "move"}], ",", "1", ",", " ", 
            RowBox[{"1", "-", "move"}]}], " ", "}"}]}], "}"}], ",", "0.02"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"plane", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGBColor", "[", 
         RowBox[{"0.4", ",", "1", ",", "0.7"}], "]"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", 
             RowBox[{"-", "1"}], ",", "m"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}], ",", "m"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1", ",", "m"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1", ",", "m"}], "}"}]}], "}"}], 
         "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"plane", ",", "cub", ",", "par", ",", "Red", ",", "bar"}], 
        "}"}], ",", 
       RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
       RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"move", ",", "0", ",", "\"\<move\>\""}], "}"}], ",", "2", ",", 
      "0"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "1"}], ",", "\"\<m\>\""}], "}"}], ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", "Manipulate"}]}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.540753149015625*^9, 3.540753409859375*^9}, {
   3.54075344078125*^9, 3.54075355559375*^9}, {3.540753609203125*^9, 
   3.540753616671875*^9}, {3.54075378978125*^9, 3.54075393103125*^9}, {
   3.5407541303125*^9, 3.540754171109375*^9}, {3.54075421284375*^9, 
   3.54075430421875*^9}, {3.540754412984375*^9, 3.540754430984375*^9}, {
   3.540754535140625*^9, 3.540754560609375*^9}, {3.54075465225*^9, 
   3.540754718359375*^9}, {3.540754760609375*^9, 3.540754778359375*^9}, {
   3.540754809609375*^9, 3.540754815453125*^9}, {3.540754961109375*^9, 
   3.540754986359375*^9}, {3.540755024203125*^9, 3.5407550294375*^9}, {
   3.540755311890625*^9, 3.5407553650625*^9}, 3.540755411296875*^9, {
   3.540755659*^9, 3.540755666921875*^9}, {3.54075575890625*^9, 
   3.540755782328125*^9}, {3.540755932875*^9, 3.54075593603125*^9}, {
   3.540755982203125*^9, 3.54075598334375*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`m$$ = -1, $CellContext`move$$ = 0, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`move$$], 0, "move"}, 2, 0}, {{
       Hold[$CellContext`m$$], -1, "m"}, -1, 1}}, Typeset`size$$ = {
    360., {178., 182.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`move$1102$$ = 
    0, $CellContext`m$1103$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`m$$ = -1, $CellContext`move$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`move$$, $CellContext`move$1102$$, 0], 
        Hold[$CellContext`m$$, $CellContext`m$1103$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ($CellContext`par = Part[
          
          ParametricPlot3D[{$CellContext`u, $CellContext`v, $CellContext`u \
$CellContext`v}, {$CellContext`u, -1, 1}, {$CellContext`v, -1, 1}, Mesh -> 
           None], 1]; $CellContext`bar = 
        Cylinder[{{1 - $CellContext`move$$, -1, -1 + $CellContext`move$$}, {
           1 - $CellContext`move$$, 1, 1 - $CellContext`move$$}}, 
          0.02]; $CellContext`plane = {
          RGBColor[0.4, 1, 0.7], 
          
          Polygon[{{-1, -1, $CellContext`m$$}, {1, -1, $CellContext`m$$}, {
            1, 1, $CellContext`m$$}, {-1, 1, $CellContext`m$$}}]}; 
       Graphics3D[{$CellContext`plane, $CellContext`cub, $CellContext`par, 
          Red, $CellContext`bar}, Boxed -> False, SphericalRegion -> True]), 
      "Specifications" :> {{{$CellContext`move$$, 0, "move"}, 2, 
         0}, {{$CellContext`m$$, -1, "m"}, -1, 1}}, 
      "Options" :> {TrackedSymbols -> Manipulate}, "DefaultOptions" :> {}],
     ImageSizeCache->{405., {236., 241.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.54075327078125*^9, 3.540753323671875*^9}, {
   3.540753522671875*^9, 3.54075355621875*^9}, 3.540753617234375*^9, {
   3.54075379546875*^9, 3.54075388121875*^9}, {3.54075391128125*^9, 
   3.540753932265625*^9}, 3.54075406709375*^9, {3.54075427875*^9, 
   3.54075430796875*^9}, {3.540754353*^9, 3.540754368453125*^9}, {
   3.54075441353125*^9, 3.540754431359375*^9}, 3.540754465671875*^9, 
   3.54075456225*^9, {3.54075469021875*^9, 3.540754719203125*^9}, 
   3.540754778703125*^9, 3.54075481621875*^9, {3.540754973390625*^9, 
   3.54075498671875*^9}, 3.540755029921875*^9, 3.5407553125*^9, {
   3.54075534609375*^9, 3.540755368890625*^9}, 3.540755412375*^9, 
   3.540755667984375*^9, {3.5407557746875*^9, 3.540755783171875*^9}, 
   3.54075587034375*^9, 3.540755937296875*^9, 3.540755983625*^9, 
   3.540756827921875*^9, {3.5407586055625*^9, 3.54075862734375*^9}, 
   3.540758774828125*^9, 3.54076119234375*^9, {3.54076130978125*^9, 
   3.540761335953125*^9}, 3.540783407265625*^9, 3.54078476478125*^9, {
   3.5408298375*^9, 3.540829839734375*^9}, 3.5408299111875*^9}]
}, Open  ]],

Cell["\<\
This can be regarded of the design of a mechanical model having the purpose \
to show that any point of the surface has equal distances to two \
perpendicular lines that are at a distance of 1/4 from the centre. The red \
cylinders represent telescoping bars, which are attached perpedicularly to \
the lines (represented here also with bar) with the help of bearings that can \
slide and rotate on the bars. The other and of the telescopic bar slides on \
the surface.\
\>", "Text",
 CellChangeTimes->{{3.540783429125*^9, 3.54078354253125*^9}, {3.540783576*^9, 
   3.5407836548125*^9}, {3.54078399946875*^9, 3.540784018640625*^9}, 
   3.540784060859375*^9, {3.540784182234375*^9, 3.5407841949375*^9}, {
   3.540784762421875*^9, 3.54078520359375*^9}, {3.5407852811875*^9, 
   3.540785294203125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"sp", "=", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"Sphere", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", " ", ",", " ", "y", "  ", ",", "  ", 
           RowBox[{"x", " ", "y"}]}], " ", "}"}], ",", "0.06"}], "]"}]}], 
      "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"cube", "=", 
     RowBox[{"PolyhedronData", "[", 
      RowBox[{"\"\<Cube\>\"", ",", "\"\<Edges\>\""}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"pp", "=", 
     RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", " ", 
         RowBox[{"u", " ", ",", "v", " ", ",", " ", 
          RowBox[{"u", " ", "v"}]}], " ", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"Mesh", "\[Rule]", "None"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"b1", "=", 
     RowBox[{"{", 
      RowBox[{"Yellow", ",", 
       RowBox[{"Cylinder", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1", ",", " ", 
             RowBox[{"1", "/", "2"}]}], " ", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}], ",", " ", 
             RowBox[{"1", "/", "2"}]}], " ", "}"}]}], "}"}], ",", "0.04"}], 
        "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"b2", "=", 
     RowBox[{"{", 
      RowBox[{"Yellow", ",", 
       RowBox[{"Cylinder", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", 
             RowBox[{"-", "1"}], ",", " ", 
             RowBox[{
              RowBox[{"-", "1"}], "/", "2"}]}], " ", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1", ",", " ", 
             RowBox[{
              RowBox[{"-", "1"}], "/", "2"}]}], " ", "}"}]}], "}"}], ",", 
         "0.04"}], "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[Alpha]", "=", 
     RowBox[{"ArcTan", "[", 
      RowBox[{"y", "/", "x"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[Beta]", "=", 
     RowBox[{"Pi", "-", 
      RowBox[{"Pi", "/", "4"}], "-", "\[Alpha]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"z", "=", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"x", "^", "2"}], "+", 
       RowBox[{"y", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"p", "=", " ", 
     RowBox[{"z", " ", 
      RowBox[{"Cos", "[", "\[Beta]", "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"u1", "=", " ", 
     RowBox[{"p", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"Pi", "/", "4"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"u2", "=", " ", 
     RowBox[{"z", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Alpha]", "-", 
        RowBox[{"Pi", "/", "4"}]}], "]"}], 
      RowBox[{"Sin", "[", 
       RowBox[{"Pi", "/", "4"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"perp1", "=", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"Cylinder", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x", ",", " ", "y", ",", "  ", 
             RowBox[{"x", " ", "y"}]}], " ", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "u1"}], ",", "u1", ",", "  ", 
             RowBox[{"1", "/", "2"}]}], " ", "}"}]}], "}"}], ",", "0.03"}], 
        "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"bearing1", "=", 
     RowBox[{"{", 
      RowBox[{"Yellow", ",", 
       RowBox[{"Cylinder", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "u1"}], "-", "0.05"}], ",", 
             RowBox[{"u1", "+", "0.05"}], ",", "  ", 
             RowBox[{"1", "/", "2"}]}], " ", " ", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "u1"}], "+", "0.05"}], ",", 
             RowBox[{"u1", "-", "0.05"}], ",", "  ", 
             RowBox[{"1", "/", "2"}]}], " ", "}"}]}], "}"}], ",", "0.1"}], 
        "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"perp2", "=", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"Cylinder", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x", " ", ",", " ", "y", " ", ",", "  ", 
             RowBox[{"x", " ", "y"}]}], " ", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"u2", ",", "u2", ",", " ", 
             RowBox[{
              RowBox[{"-", " ", "1"}], "/", "2"}]}], " ", "}"}]}], "}"}], ",",
          "0.03"}], "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"bearing2", "=", 
     RowBox[{"{", 
      RowBox[{"Yellow", ",", 
       RowBox[{"Cylinder", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"u2", "-", "0.05"}], ",", 
             RowBox[{"u2", "-", "0.05"}], ",", "  ", 
             RowBox[{
              RowBox[{"-", "1"}], "/", "2"}]}], " ", " ", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"u2", "+", "0.05"}], ",", 
             RowBox[{"u2", "+", "0.05"}], ",", "  ", 
             RowBox[{
              RowBox[{"-", "1"}], "/", "2"}]}], " ", "}"}]}], "}"}], ",", 
         "0.1"}], "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "bearing1", ",", "bearing2", ",", "perp1", ",", "perp2", ",", "sp", 
        ",", "b1", ",", "b2", ",", 
        RowBox[{"Opacity", "[", "0.9", "]"}], ",", "pp", ",", 
        RowBox[{"Scale", "[", 
         RowBox[{"cube", ",", " ", 
          RowBox[{"2", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
      RowBox[{"SphericalRegion", "\[Rule]", "True"}], ",", 
      RowBox[{"ViewPoint", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"-", "5"}], ",", "2"}], "}"}]}], ",", 
      RowBox[{"ViewAngle", "\[Rule]", "0.25"}]}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "0.01", ",", "\"\<x\>\""}], "}"}], ",", "0.01", ",", 
     "1"}], "}"}], ",", " ", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y", ",", "0.01", ",", "\"\<y\>\""}], "}"}], ",", "0.01", ",", 
     "1"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", "Manipulate"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.54031456003125*^9, 3.54031473115625*^9}, 
   3.540314798109375*^9, {3.540314855453125*^9, 3.54031486965625*^9}, {
   3.540315102703125*^9, 3.540315147953125*^9}, {3.54035569921875*^9, 
   3.5403557689375*^9}, {3.5403558726875*^9, 3.54035590578125*^9}, {
   3.5403560866875*^9, 3.540356231640625*^9}, {3.540356293078125*^9, 
   3.54035639175*^9}, {3.540356430703125*^9, 3.540356453171875*^9}, {
   3.540356556734375*^9, 3.540356616203125*^9}, {3.54035779921875*^9, 
   3.540357945796875*^9}, {3.540358002140625*^9, 3.540358052171875*^9}, {
   3.5403580823125*^9, 3.540358087140625*^9}, 3.5403581533125*^9, 
   3.540358198265625*^9, {3.540358238390625*^9, 3.540358252171875*^9}, 
   3.540358304921875*^9, {3.5403583435625*^9, 3.540358349625*^9}, {
   3.5403616233125*^9, 3.5403617445*^9}, {3.540361844484375*^9, 
   3.540361863078125*^9}, 3.540361975578125*^9, {3.540362015921875*^9, 
   3.540362062515625*^9}, {3.540362104890625*^9, 3.540362148015625*^9}, {
   3.540362275953125*^9, 3.540362310671875*^9}, 3.540362346609375*^9, {
   3.540362468890625*^9, 3.540362488390625*^9}, {3.540362798890625*^9, 
   3.540362861*^9}, {3.540362908828125*^9, 3.54036293696875*^9}, {
   3.540363056390625*^9, 3.540363078171875*^9}, {3.54036319825*^9, 
   3.54036319946875*^9}, {3.540363230484375*^9, 3.540363247*^9}, {
   3.54036328071875*^9, 3.540363310109375*^9}, {3.540363345703125*^9, 
   3.5403633568125*^9}, {3.540363896984375*^9, 3.540363975671875*^9}, {
   3.54036401434375*^9, 3.540364015578125*^9}, {3.54069048715625*^9, 
   3.540690500453125*^9}, {3.54069053075*^9, 3.540690767046875*^9}, {
   3.5406908396875*^9, 3.540690879203125*^9}, {3.540690940125*^9, 
   3.540690964421875*^9}, 3.540691068171875*^9, 3.540691179171875*^9, {
   3.540691278953125*^9, 3.54069133509375*^9}, {3.54069143259375*^9, 
   3.540691433984375*^9}, {3.540691514890625*^9, 3.540691532875*^9}, {
   3.540691564734375*^9, 3.540691567921875*^9}, {3.540691846234375*^9, 
   3.540691954140625*^9}, {3.540691988265625*^9, 3.5406919916875*^9}, {
   3.540692117609375*^9, 3.540692157515625*^9}, {3.540749226171875*^9, 
   3.540749226625*^9}, {3.540751072421875*^9, 3.54075108878125*^9}, {
   3.540752707328125*^9, 3.540752756609375*^9}, {3.5407527959375*^9, 
   3.540752813140625*^9}, {3.54075289228125*^9, 3.5407529065*^9}, {
   3.540752943078125*^9, 3.540753018234375*^9}, {3.540756018515625*^9, 
   3.540756161234375*^9}, {3.540756874203125*^9, 3.54075693665625*^9}, {
   3.5407570315*^9, 3.540757090125*^9}, {3.54075715771875*^9, 
   3.540757244546875*^9}, {3.540757290515625*^9, 3.540757290765625*^9}, {
   3.540757329109375*^9, 3.540757345875*^9}, {3.54075743678125*^9, 
   3.540757456828125*^9}, {3.5407575121875*^9, 3.540757532546875*^9}, 
   3.5407576329375*^9, {3.540757800765625*^9, 3.540757826265625*^9}, {
   3.540757866171875*^9, 3.540757887953125*^9}, {3.540758004109375*^9, 
   3.54075803225*^9}, {3.54075811659375*^9, 3.540758118703125*^9}, {
   3.54075815984375*^9, 3.54075823015625*^9}, {3.5407582745*^9, 
   3.540758355203125*^9}, {3.540758447953125*^9, 3.540758476171875*^9}, {
   3.54075871659375*^9, 3.540758722390625*^9}, {3.540758812640625*^9, 
   3.5407588353125*^9}, {3.540761269453125*^9, 3.540761269953125*^9}, {
   3.540829950765625*^9, 3.540829969078125*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`x$$ = 0.01, $CellContext`y$$ = 0.01, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`x$$], 0.01, "x"}, 0.01, 1}, {{
       Hold[$CellContext`y$$], 0.01, "y"}, 0.01, 1}}, Typeset`size$$ = {
    360., {178., 182.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`x$1328$$ = 
    0, $CellContext`y$1329$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`x$$ = 0.01, $CellContext`y$$ = 0.01}, 
      "ControllerVariables" :> {
        Hold[$CellContext`x$$, $CellContext`x$1328$$, 0], 
        Hold[$CellContext`y$$, $CellContext`y$1329$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ($CellContext`sp = {Blue, 
          
          Sphere[{$CellContext`x$$, $CellContext`y$$, $CellContext`x$$ \
$CellContext`y$$}, 0.06]}; $CellContext`cube = 
        PolyhedronData["Cube", "Edges"]; $CellContext`pp = Part[
          
          ParametricPlot3D[{$CellContext`u, $CellContext`v, $CellContext`u \
$CellContext`v}, {$CellContext`u, -1, 1}, {$CellContext`v, -1, 1}, Mesh -> 
           None], 1]; $CellContext`b1 = {Yellow, 
          Cylinder[{{-1, 1, 1/2}, {1, -1, 1/2}}, 0.04]}; $CellContext`b2 = {
         Yellow, 
          
          Cylinder[{{-1, -1, (-1)/2}, {1, 1, (-1)/2}}, 
           0.04]}; $CellContext`\[Alpha] = 
        ArcTan[$CellContext`y$$/$CellContext`x$$]; $CellContext`\[Beta] = 
        Pi - Pi/4 - $CellContext`\[Alpha]; $CellContext`z = 
        Sqrt[$CellContext`x$$^2 + $CellContext`y$$^2]; $CellContext`p = \
$CellContext`z Cos[$CellContext`\[Beta]]; $CellContext`u1 = $CellContext`p 
         Sin[Pi/4]; $CellContext`u2 = $CellContext`z 
         Cos[$CellContext`\[Alpha] - Pi/4] Sin[Pi/4]; $CellContext`perp1 = {
         Red, 
          
          Cylinder[{{$CellContext`x$$, $CellContext`y$$, $CellContext`x$$ \
$CellContext`y$$}, {-$CellContext`u1, $CellContext`u1, 1/2}}, 
           0.03]}; $CellContext`bearing1 = {Yellow, 
          
          Cylinder[{{-$CellContext`u1 - 0.05, $CellContext`u1 + 0.05, 1/
             2}, {-$CellContext`u1 + 0.05, $CellContext`u1 - 0.05, 1/2}}, 
           0.1]}; $CellContext`perp2 = {Red, 
          
          Cylinder[{{$CellContext`x$$, $CellContext`y$$, $CellContext`x$$ \
$CellContext`y$$}, {$CellContext`u2, $CellContext`u2, (-1)/2}}, 
           0.03]}; $CellContext`bearing2 = {Yellow, 
          
          Cylinder[{{$CellContext`u2 - 0.05, $CellContext`u2 - 0.05, (-1)/
             2}, {$CellContext`u2 + 0.05, $CellContext`u2 + 0.05, (-1)/2}}, 
           0.1]}; Graphics3D[{$CellContext`bearing1, $CellContext`bearing2, \
$CellContext`perp1, $CellContext`perp2, $CellContext`sp, $CellContext`b1, \
$CellContext`b2, 
          Opacity[0.9], $CellContext`pp, 
          Scale[$CellContext`cube, 2 {1, 1, 1}, {0, 0, 0}]}, Boxed -> False, 
         SphericalRegion -> True, ViewPoint -> {2, -5, 2}, ViewAngle -> 
         0.25]), "Specifications" :> {{{$CellContext`x$$, 0.01, "x"}, 0.01, 
         1}, {{$CellContext`y$$, 0.01, "y"}, 0.01, 1}}, 
      "Options" :> {TrackedSymbols -> Manipulate}, "DefaultOptions" :> {}],
     ImageSizeCache->{405., {236., 241.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.540314737203125*^9, {3.540315119125*^9, 3.540315148484375*^9}, {
   3.54035574975*^9, 3.54035576928125*^9}, 3.54035590671875*^9, {
   3.54035610675*^9, 3.54035612515625*^9}, {3.54035622328125*^9, 
   3.540356232609375*^9}, {3.54035634728125*^9, 3.54035635375*^9}, 
   3.540356392234375*^9, {3.540356431546875*^9, 3.540356454015625*^9}, 
   3.540356617171875*^9, 3.540358052578125*^9, 3.540358092828125*^9, 
   3.54035815475*^9, 3.54035820121875*^9, {3.5403582423125*^9, 
   3.5403582526875*^9}, 3.540358306484375*^9, 3.540358351109375*^9, 
   3.540361290265625*^9, 3.540361624125*^9, {3.54036168825*^9, 
   3.540361745234375*^9}, {3.54036180240625*^9, 3.54036186353125*^9}, 
   3.54036197759375*^9, {3.540362021265625*^9, 3.540362062765625*^9}, {
   3.540362105625*^9, 3.54036214871875*^9}, {3.540362279109375*^9, 
   3.54036231146875*^9}, 3.540362347328125*^9, 3.54036240534375*^9, {
   3.54036246996875*^9, 3.540362489390625*^9}, {3.540362801671875*^9, 
   3.54036296521875*^9}, {3.540363057375*^9, 3.540363080390625*^9}, 
   3.5403632*^9, {3.5403632314375*^9, 3.540363247875*^9}, 
   3.540363311984375*^9, {3.540363346671875*^9, 3.5403633576875*^9}, 
   3.540363392203125*^9, 3.54036343878125*^9, {3.54036394975*^9, 
   3.54036398140625*^9}, 3.54036401675*^9, {3.540690488375*^9, 
   3.5406905014375*^9}, {3.5406906451875*^9, 3.540690695546875*^9}, 
   3.54069076834375*^9, {3.540690871125*^9, 3.540690880171875*^9}, {
   3.540690952078125*^9, 3.540690966125*^9}, 3.54069133575*^9, 
   3.54069143509375*^9, {3.540691542203125*^9, 3.5406915696875*^9}, 
   3.540691731515625*^9, {3.540691846890625*^9, 3.540691861375*^9}, {
   3.540691902921875*^9, 3.540691954484375*^9}, {3.540692134625*^9, 
   3.54069215865625*^9}, 3.54069306084375*^9, 3.5406935101875*^9, 
   3.540749192109375*^9, 3.54074922709375*^9, 3.5407510246875*^9, 
   3.540751089703125*^9, 3.540752683046875*^9, {3.540752757421875*^9, 
   3.5407527710625*^9}, 3.540752813984375*^9, 3.54075290734375*^9, 
   3.540752955453125*^9, 3.5407530203125*^9, 3.540753110171875*^9, 
   3.540754496296875*^9, {3.540755701125*^9, 3.540755713921875*^9}, 
   3.540755951421875*^9, 3.54075599996875*^9, {3.540756039890625*^9, 
   3.540756064875*^9}, {3.54075609490625*^9, 3.540756111390625*^9}, 
   3.540756149578125*^9, {3.540756832046875*^9, 3.54075684675*^9}, 
   3.540757092125*^9, {3.540757159765625*^9, 3.54075724671875*^9}, 
   3.540757457625*^9, {3.540757522375*^9, 3.540757533265625*^9}, 
   3.540757565109375*^9, 3.54075773525*^9, 3.540757827625*^9, 
   3.540757889359375*^9, {3.540758009203125*^9, 3.54075803309375*^9}, 
   3.54075819190625*^9, 3.54075823090625*^9, {3.540758335140625*^9, 
   3.5407583564375*^9}, 3.540758477359375*^9, {3.540758608046875*^9, 
   3.540758629796875*^9}, {3.540758800015625*^9, 3.540758851953125*^9}, 
   3.540761237953125*^9, 3.540761312859375*^9, 3.5407848494375*^9, 
   3.54082984496875*^9, 3.540829911359375*^9, {3.54082995959375*^9, 
   3.540829969390625*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{716, 475},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 155, 2, 71, "Section"],
Cell[737, 26, 570, 9, 83, "Text"],
Cell[CellGroupData[{
Cell[1332, 39, 3795, 95, 232, "Input"],
Cell[5130, 136, 3268, 62, 484, "Output"]
}, Open  ]],
Cell[8413, 201, 592, 10, 83, "Text"],
Cell[CellGroupData[{
Cell[9030, 215, 3660, 89, 212, "Input"],
Cell[12693, 306, 3580, 64, 494, "Output"]
}, Open  ]],
Cell[16288, 373, 809, 13, 83, "Text"],
Cell[CellGroupData[{
Cell[17122, 390, 10409, 241, 532, "Input"],
Cell[27534, 633, 6942, 121, 494, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
